/***************************************************************
 * Name:      calendar.cpp
 * Purpose:   Code for Dialog calendar
 * Author:    Salvador Pozo (salvapozo@gmail.com)
 * Created:   2024-12-25
 * Copyright: Salvador Pozo (https://conclase.net)
 * License:
 **************************************************************/

#include "calendar.h"

wxBEGIN_EVENT_TABLE(calendar, wxDialog)
    EVT_CLOSE(calendar::OnClose)
    EVT_CALENDAR(idCalendar, calendar::OnCalendar)
    EVT_CALENDAR_YEAR(idCalendar, calendar::OnCambioAnno)
    EVT_CALENDAR_PAGE_CHANGED(idCalendar, calendar::OnCambioMes)
    EVT_BUTTON(wxID_OK, calendar::OnOk)
wxEND_EVENT_TABLE()

calendar::calendar(wxWindow *wnd, datosCalendar &datos)
    : wxDialog(wnd, -1, _T("Ejemplo de calendario")), data(datos)
{
    wxBoxSizer *boxVertical;
    wxBoxSizer *boxHorizontal;
    wxDateTime fInicio, fFinal;
    wxDateSpan span;

    if(data.valor == wxDefaultDateTime) data.valor = wxDateTime::Today();
    AsignarAutoridad(data.valor.GetYear());

    boxVertical = new wxBoxSizer(wxVERTICAL);

    boxHorizontal = new wxBoxSizer(wxHORIZONTAL);
    m_calendar = new wxGenericCalendarCtrl(this, idCalendar, datos.valor, wxDefaultPosition, wxDefaultSize,
        wxCAL_SHOW_HOLIDAYS | wxCAL_SHOW_WEEK_NUMBERS | wxCAL_SEQUENTIAL_MONTH_SELECTION);

    MarcarHoy(data.valor);

    fInicio = data.valor - wxDateSpan(1, 3, 0, -5); // Desde un año, tres meses menos 5 días antes
    fFinal = data.valor + wxDateSpan(0, 2, 0, 10);  // Hast dos meses y 10 días después

    m_calendar->SetDateRange(fInicio, fFinal);
    boxHorizontal->Add(m_calendar, wxSizerFlags().Border());
    boxVertical->Add(boxHorizontal, wxSizerFlags().Border(wxTOP).Right());

    boxVertical->Add(CreateStdDialogButtonSizer(wxOK | wxCANCEL), wxSizerFlags().Border());

    SetSizerAndFit(boxVertical);
}

calendar::~calendar() {}

void calendar::OnClose(wxCloseEvent& event) {
    Destroy();
}

void calendar::OnOk(wxCommandEvent& event) {
    data.valor = m_calendar->GetDate();
    Destroy();
}

void calendar::OnCalendar(wxCalendarEvent& event) {
    data.valor = event.GetDate();
    Destroy();
}

void calendar::OnCambioAnno(wxCalendarEvent& event) {
    AsignarAutoridad(event.GetDate().GetYear());
    m_calendar->EnableHolidayDisplay(false);
    m_calendar->EnableHolidayDisplay(true);
}

void calendar::OnCambioMes(wxCalendarEvent& event) {
    MarcarHoy(event.GetDate());
}

void calendar::AsignarAutoridad(int year) {
    wxFileStream fe("fiestas.txt");
    if(!fe.IsOk()) return;

    wxDateTime dt;
    wxString cad;
    char buffer[20];
    wxString::const_iterator end;

    wxDateTimeHolidayAuthority::ClearAllAuthorities();

    wxDateTimeFestivos* festivos = new wxDateTimeFestivos;
    while(!fe.Eof()) {
        if(!fe.Read(buffer, 12).Eof()) {
            cad = wxString(buffer);
            if(dt.ParseFormat(cad, "%d/%m/%Y", &end) && year==dt.GetYear()) {
                festivos->InsertarFestivo(dt);
            }
        }
    }
    wxDateTimeHolidayAuthority::AddAuthority(new wxDateTimeDomingos);
    wxDateTimeHolidayAuthority::AddAuthority(festivos);
}

void calendar::MarcarHoy(const wxDateTime& dt) {
    if(dt.GetYear() == wxDateTime::Today().GetYear() &&
       dt.GetMonth() == wxDateTime::Today().GetMonth()) {
        m_calendar->Mark(wxDateTime::Today().GetDay(), true);
    } else {
        m_calendar->Mark(wxDateTime::Today().GetDay(), false);
    }
}
