/***************************************************************
 * Name:      datepicker.cpp
 * Purpose:   Code for Dialog datepicker
 * Author:    Salvador Pozo (salvapozo@gmail.com)
 * Created:   2024-12-29
 * Copyright: Salvador Pozo (https://conclase.net)
 * License:
 **************************************************************/

#include "datepicker.h"

IMPLEMENT_DYNAMIC_CLASS( dpValidator, wxValidator )
BEGIN_EVENT_TABLE( dpValidator, wxValidator )
END_EVENT_TABLE()

bool dpValidator::TransferFromWindow()
{
    try {
        wxDatePickerCtrl *dp = dynamic_cast<wxDatePickerCtrl*>(m_validatorWindow);
        *m_valor = dp->GetValue();
    }
    catch (...) {
        wxFAIL_MSG( _T("dpValidator sólo funciona con wxDatePicker"));
        return false;
    }
    return true;
}

wxBEGIN_EVENT_TABLE(datepicker, wxDialog)
    EVT_CLOSE(datepicker::OnClose)
wxEND_EVENT_TABLE()

datepicker::datepicker(wxWindow *wnd, datosDatePicker &datos)
    : wxDialog(wnd, -1, _T("Ejemplo de datepicker")), data(datos)
{
    wxBoxSizer *boxVertical;
    wxBoxSizer *boxHorizontal;
    wxDateTime fInicio, fFinal;

    if(data.valor == wxDefaultDateTime) data.valor = wxDateTime::Today();

    boxVertical = new wxBoxSizer(wxVERTICAL);

    boxHorizontal = new wxBoxSizer(wxHORIZONTAL);
    m_datepicker = new wxDatePickerCtrl(this, iddatepicker, datos.valor, wxDefaultPosition, wxDefaultSize,
        wxDP_SPIN|wxDP_SHOWCENTURY, dpValidator(&datos.valor));

    fInicio = data.valor - wxDateSpan(0, 3, 0, -5); // Desde tres meses menos 5 días antes
    fFinal = data.valor + wxDateSpan(0, 2, 0, 10);  // Hast dos meses y 10 días después

    m_datepicker->SetRange(fInicio, fFinal);
    boxHorizontal->Add(m_datepicker, wxSizerFlags().Border());
    boxVertical->Add(boxHorizontal, wxSizerFlags().Border(wxTOP).Right());

    boxVertical->Add(CreateStdDialogButtonSizer(wxOK | wxCANCEL), wxSizerFlags().Border());

    SetSizerAndFit(boxVertical);
}

datepicker::~datepicker() {}

void datepicker::OnClose(wxCloseEvent& event) {
    Destroy();
}
