/***************************************************************
 * Name:      timepicker.cpp
 * Purpose:   Code for Dialog timepicker
 * Author:    Salvador Pozo (salvapozo@gmail.com)
 * Created:   2024-12-29
 * Copyright: Salvador Pozo (https://conclase.net)
 * License:
 **************************************************************/

#include "timepicker.h"

IMPLEMENT_DYNAMIC_CLASS( tpValidator, wxValidator )
BEGIN_EVENT_TABLE( tpValidator, wxValidator )
END_EVENT_TABLE()

bool tpValidator::TransferFromWindow()
{
    try {
        wxTimePickerCtrl *dp = dynamic_cast<wxTimePickerCtrl*>(m_validatorWindow);
        *m_valor = dp->GetValue();
    }
    catch (...) {
        wxFAIL_MSG( _T("tpValidator sólo funciona con wxTimePicker"));
        return false;
    }
    return true;
}

wxBEGIN_EVENT_TABLE(timepicker, wxDialog)
    EVT_CLOSE(timepicker::OnClose)
wxEND_EVENT_TABLE()

timepicker::timepicker(wxWindow *wnd, datosTimePicker &datos)
    : wxDialog(wnd, -1, _T("Ejemplo de timepicker")), data(datos)
{
    wxBoxSizer *boxVertical;
    wxBoxSizer *boxHorizontal;

    if(data.valor == wxDefaultDateTime) data.valor = wxDateTime::Today();

    boxVertical = new wxBoxSizer(wxVERTICAL);

    boxHorizontal = new wxBoxSizer(wxHORIZONTAL);
    m_timepicker = new wxTimePickerCtrl(this, idtimepicker, datos.valor, wxDefaultPosition, wxDefaultSize,
        0, tpValidator(&datos.valor));
    boxHorizontal->Add(m_timepicker, wxSizerFlags().Border());
    boxVertical->Add(boxHorizontal, wxSizerFlags().Border(wxTOP).Right());

    boxVertical->Add(CreateStdDialogButtonSizer(wxOK | wxCANCEL), wxSizerFlags().Border());

    SetSizerAndFit(boxVertical);
}

timepicker::~timepicker() {}

void timepicker::OnClose(wxCloseEvent& event) {
    Destroy();
}

