/***************************************************************
 * Name:      wx014Main.cpp
 * Purpose:   Code for Application Frame
 * Author:    Salvador Pozo (salvador@conclase.net)
 * Created:   2024-12-25
 * Copyright: Salvador Pozo (https://conclase.net)
 * License:
 **************************************************************/

#ifdef WX_PRECOMP
#include "wx_pch.h"
#endif

#include "wx014Main.h"

//helper functions
enum wxbuildinfoformat {
    short_f, long_f };

wxString wxbuildinfo(wxbuildinfoformat format)
{
    wxString wxbuild(wxVERSION_STRING);

    if (format == long_f )
    {
#if defined(__WXMSW__)
        wxbuild << _T("-Windows");
#elif defined(__WXMAC__)
        wxbuild << _T("-Mac");
#elif defined(__UNIX__)
        wxbuild << _T("-Linux");
#endif

#if wxUSE_UNICODE
        wxbuild << _T("-Unicode build");
#else
        wxbuild << _T("-ANSI build");
#endif // wxUSE_UNICODE
    }

    return wxbuild;
}

BEGIN_EVENT_TABLE(wx014Frame, wxFrame)
    EVT_CLOSE(wx014Frame::OnClose)
    EVT_MENU(idMenuQuit, wx014Frame::OnQuit)
    EVT_MENU(idMenuAbout, wx014Frame::OnAbout)
    EVT_MENU(idMenuCalendar, wx014Frame::OnCalendar)
    EVT_MENU(idMenuDatePicker, wx014Frame::OnDatePicker)
    EVT_MENU(idMenuTimePicker, wx014Frame::OnTimePicker)
END_EVENT_TABLE()

wx014Frame::wx014Frame(wxFrame *frame, const wxString& title)
    : wxFrame(frame, -1, title)
{
    // create a menu bar
    wxMenuBar* mbar = new wxMenuBar();
    wxMenu* fileMenu = new wxMenu(_T(""));
    fileMenu->Append(idMenuCalendar, _T("&Calendar"), _T("Ejemplo de Calendar"));
    fileMenu->Append(idMenuDatePicker, _T("&Datepicker"), _T("Ejemplo de Datepicker"));
    fileMenu->Append(idMenuTimePicker, _T("&Timepicker"), _T("Ejemplo de timepicker"));
    fileMenu->Append(idMenuQuit, _T("&Salir\tAlt-F4"), _T("Salir de la aplicación"));
    mbar->Append(fileMenu, _T("&Fichero"));

    wxMenu* helpMenu = new wxMenu(_T(""));
    helpMenu->Append(idMenuAbout, _T("&Sobre\tF1"), _T("Muestra información sobre la aplicación"));
    mbar->Append(helpMenu, _T("&Ayuda"));

    SetMenuBar(mbar);

    // create a status bar with some information about the used wxWidgets version
    CreateStatusBar(2);
    SetStatusText(_("Hola"),0);
    SetStatusText(wxbuildinfo(short_f), 1);
}


wx014Frame::~wx014Frame()
{
}

void wx014Frame::OnClose(wxCloseEvent &event)
{
    Destroy();
}

void wx014Frame::OnQuit(wxCommandEvent &event)
{
    Destroy();
}

void wx014Frame::OnAbout(wxCommandEvent &event)
{
    wxString msg = wxbuildinfo(long_f);
    wxMessageBox(msg, _("Bienvenido a ..."));
}

void wx014Frame::OnCalendar(wxCommandEvent& event)
{
    wxString cad;
    calendar *dlg = new calendar(this, dataCalendar);
    dlg->ShowModal();

    cad = dataCalendar.valor.Format(_T("Fecha: %A %d de %B de %Y"));

    wxMessageBox(cad, _T("Respuesta"));
}

void wx014Frame::OnDatePicker(wxCommandEvent& event)
{
    wxString cad;
    datepicker *dlg = new datepicker(this, dataDatepicker);
    dlg->ShowModal();

    cad = dataDatepicker.valor.Format(_T("Fecha: %A %d de %B de %Y"));

    wxMessageBox(cad, _T("Respuesta"));
}

void wx014Frame::OnTimePicker(wxCommandEvent& event)
{
    wxString cad;
    timepicker *dlg = new timepicker(this, dataTimepicker);
    dlg->ShowModal();

    cad = dataTimepicker.valor.Format(_T("Hora: %H:%M:%S"));

    wxMessageBox(cad, _T("Respuesta"));
}

